@@ -1,5 +1,5 @@
 package ExtUtils::Typemaps::Signal;
-$ExtUtils::Typemaps::Signal::VERSION = '0.001';
+$ExtUtils::Typemaps::Signal::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -80,7 +80,7 @@ END
 
 1;
 
-#ABSTRACT: asdasd
+#ABSTRACT: A typemap for dealing with signal related types
 
 __END__
 
@@ -90,11 +90,11 @@ __END__
 
 =head1 NAME
 
-ExtUtils::Typemaps::Signal - asdasd
+ExtUtils::Typemaps::Signal - A typemap for dealing with signal related types
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
